@@ -2,7 +2,7 @@
 
 ###
 ### $Release: $
-### $Copyright: copyright(c) 2010-2011 kuwata-lab.com all rights reserved $
+### $Copyright: copyright(c) 2010-2014 kuwata-lab.com all rights reserved $
 ### $License: MIT License $
 ###
 
@@ -20,8 +20,8 @@ from glob import glob
 from kook.utils import read_file, write_file
 
 package   = prop('package', 'Oktest')
-release   = prop('release', '0.11.1')
-copyright = prop('copyright', "copyright(c) 2010-2011 kuwata-lab.com all rights reserved")
+release   = prop('release', '0.12.0')
+copyright = prop('copyright', "copyright(c) 2010-2014 kuwata-lab.com all rights reserved")
 license   = "MIT License"
 python    = prop('python', sys.executable)
 basename  = "%s-%s" % (package, release)
@@ -62,9 +62,9 @@ def _with_backup(filepath):
     return deco
 
 
-TEST_NAMES = ('tracer', 'spec', 'testdeco',
+TEST_NAMES = ('tracer', 'spec', 'testdeco', 'fixture',
               'doc', 'assertions', 'dummy', 'runner', 'context', 'reporter',
-              'util', 'skip', 'todo', 'mainapp', )
+              'util', 'skip', 'todo', 'resp', 'mainapp', )
 test_names = [ os.path.basename(x).replace('_test.py', '')
                    for x in glob("test/*_test.py") ]
 assert set(TEST_NAMES) == set(test_names)
@@ -292,31 +292,48 @@ def task_manifest(c):
     system(c%'$(python) setup.py sdist --force-manifest')
 
 
-def replacer(s):
-    #s = re.sub(r'\$Package\$',   package,   s)
-    #s = re.sub(r'\$Release\$',   release,   s)
-    #s = re.sub(r'\$Copyright\$', copyright, s)
-    #s = re.sub(r'\$License\$',   license,   s)
-    s = re.sub(r'\$Package:[^%]*?\$',    '$Package: %s $'   % package,   s)
-    s = re.sub(r'\$Release:[^%]*?\$',    '$Release: %s $'   % release,   s)
-    s = re.sub(r'\$Copyright:[^%]*?\$',  '$Copyright: %s $' % copyright, s)
-    s = re.sub(r'\$License:[^%]*?\$',    '$License: %s $'   % license,   s)
-    s = re.sub(r'%s-\d+\.\d+\.\d+' % package, '%s-%s' % (package, release), s)
-    return s
+replacer = [
+    #(r'\$'r'Package\$',   package),
+    #(r'\$'r'Release\$',   release),
+    #(r'\$'r'Copyright\$', copyright),
+    #(r'\$'r'License\$',   license),
+    (r'\$'r'Package:[^%]*?\$',    '$''Package: %s $'   % package),
+    (r'\$'r'Release:[^%]*?\$',    '$''Release: %s $'   % release),
+    (r'\$'r'Copyright:[^%]*?\$',  '$''Copyright: %s $' % copyright),
+    (r'\$'r'License:[^%]*?\$',    '$''License: %s $'   % license),
+    (r'%s-\d+\.\d+\.\d+' % package, '%s-%s' % (package, release)),
+]
 
 
 @recipe
-def task_edit(c):
+@spices("--copyright: update only $""Copyright$",
+        "--license:   update only $""License$",
+        "[filenames]")
+def task_edit(c, *args, **kwargs):
     """update $Release$, $Copyrigh$, and $License$ in files"""
-    filenames = read_file('MANIFEST').splitlines()
-    filenames.remove('Kookbook.py')
-    filenames.append('website/index.html')
-    edit(filenames, by=replacer)
+    if args:
+        filenames = args
+    else:
+        with open('MANIFEST') as f:
+            filenames = [ line.strip() for line in f if not line.startswith('#') ]
+        #filenames.remove('Kookbook.py')
+        filenames.append('website/index.html')
+    if 'copyright' in kwargs:
+        replacer_ = [ t for t in replacer if t[0].find('Copyright') >= 0 ]
+        patternstr = 'Copyright'
+    elif 'license' in kwargs:
+        replacer_ = [ t for t in replacer if t[0].find('License') >= 0 ]
+        patternstr = 'License'
+    else:
+        replacer_ = replacer[:]
+        patternstr = 'Package|Release|Copyright|License'
+    edit(filenames, by=replacer_)
     #
     def repl(s):
-        pat = r"^([ \t]*\w+\s*=\s*)'.*?'(\s*##\s*\$(?:Package|Release|License): (.*?) \$)"
+        pat = r"^([ \t]*\w+\s*=\s*)'.*?'(\s*##\s*\$(?:"+patternstr+r"): (.*?) \$)"
         return re.compile(pat, re.M).sub(r"\1'\3'\2", s)
-    edit('setup.py', by=repl)
+    if 'setup.py' in filenames:
+        edit('setup.py', by=repl)
 
 
 
@@ -336,7 +353,7 @@ def file_website_index_html(c):
     system(c%'rst2html.py $(opts) $(ingred) > $(product)')
     def f(s):
         s = s.replace('0.0.0', release)
-        s = s.replace('$Release$', release)
+        s = s.replace('$''Release$', release)
         s = re.sub('<\?xml version=".*" encoding=".*" *\?>\n', '', s)
         s = s.replace('Oktest README', 'Oktest - a new style testing library -')
         s = s.replace('See CHANGES.txt', 'See <a href="CHANGES.txt">CHANGES.txt</a>')
