@@ -1,6 +1,7 @@
+# -*- coding: utf-8 -*-
 ###
-### $Release: 0.11.1 $
-### $Copyright: copyright(c) 2010-2011 kuwata-lab.com all rights reserved $
+### $Release: 0.12.0 $
+### $Copyright: copyright(c) 2010-2014 kuwata-lab.com all rights reserved $
 ### $License: MIT License $
 ###
 
@@ -184,6 +185,21 @@ class Assertions_TC(unittest.TestCase):
         def fn(): ok (10).not_in(L)
 
 
+    def test_contains(self):
+        L = [10, 20, 30]
+        ok (L).contains(10)
+        ok (L).contains(20)
+        ok (L).contains(30)
+        @be_fail("11 in [10, 20, 30] : failed.")
+        def fn(): ok (L).contains(11)
+
+    def test_not_contain(self):
+        L = [10, 20, 30]
+        ok (L).not_contain(11)
+        @be_fail("10 not in [10, 20, 30] : failed.")
+        def fn(): ok (L).not_contain(10)
+
+
     global Val
     class Val(object):
         def __init__(self, val):
@@ -467,6 +483,41 @@ attr('val'): 'aaa\nbbb\nccc\n' == 'aaa\nbbbb\nccc\n' : failed.
             os.rmdir(dname)
 
 
+    def test_is_truthy(self):
+        ok (True).is_truthy()
+        ok (1).is_truthy()
+        ok ([1]).is_truthy()
+        @be_fail("bool(False) == True : failed.")
+        def fn(): ok (False).is_truthy()
+        @be_fail("bool(None) == True : failed.")
+        def fn(): ok (None).is_truthy()
+        @be_fail("bool('') == True : failed.")
+        def fn(): ok ('').is_truthy()
+        @be_fail("bool([]) == True : failed.")
+        def fn(): ok ([]).is_truthy()
+        @be_fail("bool({}) == True : failed.")
+        def fn(): ok ({}).is_truthy()
+
+
+    def test_is_falsy(self):
+        ok (False).is_falsy()
+        ok (None).is_falsy()
+        ok (0).is_falsy()
+        ok ('').is_falsy()
+        ok ([]).is_falsy()
+        ok ({}).is_falsy()
+        @be_fail("bool(True) == False : failed.")
+        def fn(): ok (True).is_falsy()
+        @be_fail("bool(1) == False : failed.")
+        def fn(): ok (1).is_falsy()
+        @be_fail("bool('x') == False : failed.")
+        def fn(): ok ('x').is_falsy()
+        @be_fail("bool([1]) == False : failed.")
+        def fn(): ok ([1]).is_falsy()
+        @be_fail("bool({'x': 1}) == False : failed.")
+        def fn(): ok ({'x':1}).is_falsy()
+
+
     ## ------------------------------------------------------------
 
 
@@ -606,7 +657,7 @@ FAILED (failures=1)
         self.assertEqual(expected, output)
 
 
-    def test_checking_testd_or_not(self):
+    def test_checking_tested_or_not(self):
         ## checking tested or not
         desc = "checking tested or not"
         script = r"""
