@@ -1,6 +1,7 @@
+# -*- coding: utf-8 -*-
 ###
-### $Release: 0.11.1 $
-### $Copyright: copyright(c) 2010-2011 kuwata-lab.com all rights reserved $
+### $Release: 0.12.0 $
+### $Copyright: copyright(c) 2010-2014 kuwata-lab.com all rights reserved $
 ### $License: MIT License $
 ###
 #from __future__ import with_statement
@@ -16,6 +17,7 @@ py27 = major == 2 and minor == 7
 py30 = major == 3 and minor == 0
 py31 = major == 3 and minor == 1
 py32 = major == 3 and minor >= 2
+py33 = major == 3 and minor >= 3
 #
 py271 = major == 2 and minor == 7 and teeny <= 1
 py314 = major == 3 and minor == 1 and teeny >= 4
@@ -69,11 +71,11 @@ from oktest import ok, NG, test, fail, skip, todo
 
 class SosTest(unittest.TestCase):
     # passed
-    @test("1+1 should be 2")
+    @test("1+1 should be 2", tag='tag1')
     def _(self):
         ok (1+1) == 2
     # failed
-    @test("1-1 should be 0")
+    @test("1-1 should be 0", tag='tag2')
     def _(self):
         ok (1-1) == 2
     # error
@@ -104,7 +106,7 @@ if __name__ == "__main__":
 
 OUTPUT_ERRORS1 = r"""
 <r>----------------------------------------------------------------------</r>
-[<R>Failed</R>] SosTest > 002: 1-1 should be 0
+[<R>Fail</R>] SosTest > 002: 1-1 should be 0
   File "_test.d/_sos_test.py", line 14, in _
     ok (1-1) == 2
 <R>AssertionError: 0 == 2 : failed.</R>
@@ -118,12 +120,12 @@ OUTPUT_ERRORS1 = r"""
 
 OUTPUT_ERRORS2 = r"""
 <r>----------------------------------------------------------------------</r>
-[<R>Failed</R>] Sos_TC > test_bbb()
+[<R>Fail</R>] Sos_TC > test_bbb()
   File "_test.d/_sos_test.py", line 34, in test_bbb
     ok ("bbb") == "aaa"
 <R>AssertionError: 'bbb' == 'aaa' : failed.</R>
---- expected 
-+++ actual 
+--- expected
++++ actual
 @@ -1,1 +1,1 @@
 -aaa
 +bbb
@@ -133,7 +135,7 @@ OUTPUT_ERRORS2 = r"""
 if py27 or py314 or py32:
     OUTPUT_ERRORS2 = r"""
 <r>----------------------------------------------------------------------</r>
-[<R>Failed</R>] Sos_TC > test_bbb()
+[<R>Fail</R>] Sos_TC > test_bbb()
   File "_test.d/_sos_test.py", line 34, in test_bbb
     ok ("bbb") == "aaa"
 <R>AssertionError: 'bbb' == 'aaa' : failed.</R>
@@ -149,21 +151,21 @@ if py27 or py314 or py32:
 
 
 OUTPUT_FOOTER = r"""
-## total:7, <G>passed:2</G>, <R>failed:2</R>, <R>error:1</R>, <Y>skipped:1</Y>, <Y>todo:1</Y>  (0.000 sec)
+## total:7, <G>pass:2</G>, <R>fail:2</R>, <R>error:1</R>, <Y>skip:1</Y>, <Y>todo:1</Y>  (0.000 sec)
 """[1:]
 
 
 OUTPUT_VERBOSE_BASE = r"""
 * <b>SosTest</b>
-  - [<G>passed</G>] 1+1 should be 2
-  - [<R>Failed</R>] 1-1 should be 0
+  - [<G>pass</G>] 1+1 should be 2
+  - [<R>Fail</R>] 1-1 should be 0
   - [<R>ERROR</R>] should raise NameError
-  - [<Y>skipped</Y>] never done (reason: REASON)
+  - [<Y>skip</Y>] never done (reason: REASON)
   - [<Y>TODO</Y>] not yet
 """[1:] + OUTPUT_ERRORS1 + r"""
 * <b>Sos_TC</b>
-  - [<G>passed</G>] test_aaa
-  - [<R>Failed</R>] test_bbb
+  - [<G>pass</G>] test_aaa
+  - [<R>Fail</R>] test_bbb
 """[1:] + OUTPUT_ERRORS2 + OUTPUT_FOOTER
 
 OUTPUT_SIMPLE_BASE = r"""
@@ -222,8 +224,8 @@ Traceback (most recent call last):
   File "_test.d/_sos_test.py", line 34, in test_bbb
     ok ("bbb") == "aaa"
 AssertionError: 'bbb' == 'aaa' : failed.
---- expected 
-+++ actual 
+--- expected
++++ actual
 @@ -1,1 +1,1 @@
 -aaa
 +bbb
@@ -295,9 +297,9 @@ ERROR: never done
 Traceback (most recent call last):
   File "/usr/local/lib/python/unittest.py", line 254, in run
     testMethod()
-  File "/usr/local/lib/python/site-packages/oktest.py", line 1819, in newfunc
+  File "/usr/local/lib/python/site-packages/oktest.py", line 2175, in newfunc
     return orig_func(self)
-  File "/usr/local/lib/python/site-packages/oktest.py", line 526, in fn
+  File "/usr/local/lib/python/site-packages/oktest.py", line 809, in fn
     raise SkipTest(reason)
 oktest.SkipTest: REASON
 
@@ -305,11 +307,11 @@ oktest.SkipTest: REASON
 ERROR: not yet
 ----------------------------------------------------------------------
 Traceback (most recent call last):
-  File "/usr/local/lib/python/site-packages/oktest.py", line 547, in deco
+  File "/usr/local/lib/python/site-packages/oktest.py", line 830, in deco
     func(*args, **kwargs)
   File "_test.d/_sos_test.py", line 28, in _
     fail("msg")
-  File "/usr/local/lib/python/site-packages/oktest.py", line 470, in fail
+  File "/usr/local/lib/python/site-packages/oktest.py", line 743, in fail
     raise AssertionError(desc)
 AssertionError: msg
 
@@ -318,9 +320,9 @@ During handling of the above exception, another exception occurred:
 Traceback (most recent call last):
   File "/usr/local/lib/python/unittest.py", line 254, in run
     testMethod()
-  File "/usr/local/lib/python/site-packages/oktest.py", line 1819, in newfunc
+  File "/usr/local/lib/python/site-packages/oktest.py", line 2175, in newfunc
     return orig_func(self)
-  File "/usr/local/lib/python/site-packages/oktest.py", line 550, in deco
+  File "/usr/local/lib/python/site-packages/oktest.py", line 833, in deco
     raise _ExpectedFailure(sys.exc_info())
 oktest._ExpectedFailure: expected failure
 
@@ -339,8 +341,8 @@ Traceback (most recent call last):
   File "_test.d/_sos_test.py", line 34, in test_bbb
     ok ("bbb") == "aaa"
 AssertionError: 'bbb' == 'aaa' : failed.
---- expected 
-+++ actual 
+--- expected
++++ actual
 @@ -1,1 +1,1 @@
 -aaa
 +bbb
@@ -369,11 +371,11 @@ ERROR: test_005: not yet (_sos_test.SosTest)
 not yet
 ----------------------------------------------------------------------
 Traceback (most recent call last):
-  File "/usr/local/lib/python/site-packages/oktest.py", line 547, in deco
+  File "/usr/local/lib/python/site-packages/oktest.py", line 830, in deco
     func(*args, **kwargs)
   File "_test.d/_sos_test.py", line 28, in _
     fail("msg")
-  File "/usr/local/lib/python/site-packages/oktest.py", line 470, in fail
+  File "/usr/local/lib/python/site-packages/oktest.py", line 743, in fail
     raise AssertionError(desc)
 AssertionError: msg
 
@@ -382,9 +384,9 @@ During handling of the above exception, another exception occurred:
 Traceback (most recent call last):
   File "/usr/local/lib/python/unittest.py", line 480, in run
     testMethod()
-  File "/usr/local/lib/python/site-packages/oktest.py", line 1819, in newfunc
+  File "/usr/local/lib/python/site-packages/oktest.py", line 2175, in newfunc
     return orig_func(self)
-  File "/usr/local/lib/python/site-packages/oktest.py", line 550, in deco
+  File "/usr/local/lib/python/site-packages/oktest.py", line 833, in deco
     raise _ExpectedFailure(sys.exc_info())
 oktest._ExpectedFailure: expected failure
 
@@ -404,8 +406,8 @@ Traceback (most recent call last):
   File "_test.d/_sos_test.py", line 34, in test_bbb
     ok ("bbb") == "aaa"
 AssertionError: 'bbb' == 'aaa' : failed.
---- expected 
-+++ actual 
+--- expected
++++ actual
 @@ -1,1 +1,1 @@
 -aaa
 +bbb
@@ -497,6 +499,9 @@ class OktestMainApp_TC(unittest.TestCase):
         expected = expected.replace('mainapp_test.py', basename)
         if py24:
             expected = expected.replace('Usage:', 'usage:')
+        if py33:
+            expected = expected.replace('option requires an argument',
+                                        'option requires 1 argument')
         return expected
 
 
@@ -611,7 +616,7 @@ mainapp_test.py: error: 'default': unknown report sytle (plain/simple/verbose, o
 
     def test_main__pattern(self):
         expected = r"""
-## total:0, passed:0, failed:0, error:0, skipped:0, todo:0  (0.000 sec)
+## total:0, pass:0, fail:0, error:0, skip:0, todo:0  (0.000 sec)
 """[1:]
         #
         sout, serr, ex = self._run_app('-p', 'test_*.py', '--color=true')
@@ -647,10 +652,10 @@ mainapp_test.py: error: -p option requires an argument
     def test_main__filter__class(self):
         expected = r"""
 * <b>Sos_TC</b>
-  - [<G>passed</G>] test_aaa
-  - [<R>Failed</R>] test_bbb
+  - [<G>pass</G>] test_aaa
+  - [<R>Fail</R>] test_bbb
 """[1:] + OUTPUT_ERRORS2 + r"""
-## total:2, <G>passed:1</G>, <R>failed:1</R>, error:0, skipped:0, todo:0  (0.000 sec)
+## total:2, <G>pass:1</G>, <R>fail:1</R>, error:0, skip:0, todo:0  (0.000 sec)
 """[1:]
         expected = Color._colorize(expected)
         #
@@ -662,8 +667,8 @@ mainapp_test.py: error: -p option requires an argument
         expected = r"""
 * <b>SosTest</b>
 * <b>Sos_TC</b>
-  - [<G>passed</G>] test_aaa
-## total:1, <G>passed:1</G>, failed:0, error:0, skipped:0, todo:0  (0.000 sec)
+  - [<G>pass</G>] test_aaa
+## total:1, <G>pass:1</G>, fail:0, error:0, skip:0, todo:0  (0.000 sec)
 """[1:]
         expected = Color._colorize(expected)
         #
@@ -674,6 +679,19 @@ mainapp_test.py: error: -p option requires an argument
         self._chk((expected, "", 0), (sout, serr, ex))
 
 
+    def test_main__filter__tag(self):
+        expected = r"""
+* <b>SosTest</b>
+  - [<G>pass</G>] 1+1 should be 2
+* <b>Sos_TC</b>
+## total:1, <G>pass:1</G>, fail:0, error:0, skip:0, todo:0  (0.000 sec)
+"""[1:]
+        expected = Color._colorize(expected)
+        #
+        sout, serr, ex = self._run_app('-f', 'tag=tag1', '--color=true')
+        self._chk((expected, "", 0), (sout, serr, ex))
+
+
 
 if __name__ == '__main__':
     unittest.main()
