@@ -1,6 +1,7 @@
+# -*- coding: utf-8 -*-
 ###
-### $Release: 0.11.1 $
-### $Copyright: copyright(c) 2010-2011 kuwata-lab.com all rights reserved $
+### $Release: 0.12.0 $
+### $Copyright: copyright(c) 2010-2014 kuwata-lab.com all rights reserved $
 ### $License: MIT License $
 ###
 
@@ -12,9 +13,10 @@ except ImportError:
     from io import StringIO
 
 import oktest
-from oktest import ok, not_ok, NG, test
+from oktest import ok, not_ok, NG, test, at_end
 from oktest.dummy import dummy_io
 from oktest.util import Color
+from oktest.tracer import Tracer
 import oktest.config
 
 echo = sys.stdout.write
@@ -312,6 +314,59 @@ tearDown() called.
         self.do_test(desc, script, expected)
 
 
+    class _MultipleErrorsTest(object):
+        def setUp(self):
+            pass
+        def tearDown(self):
+            raise RuntimeError("*** tearDown() ***")
+        #
+        def provide_x(self):
+            @at_end
+            def _():
+                raise RuntimeError("*** @at_end ***")
+            return "X"
+        def provide_y(self):
+            return "Y"
+        #def release_y(self, value):
+        #    raise RuntimeError("*** release_y() ***")
+        #
+        @test("test_1")
+        def test_1(self, x, y):
+            assert False, '*** failed ***'
+        @test("test_2")
+        def test_2(self, x, y):
+            raise RuntimeError("*** test_2() ***")
+
+    def test_multiple_errors(self):
+        testclass = self._MultipleErrorsTest
+        reporter = oktest.Reporter()
+        runner = oktest.TestRunner(reporter)
+        tr = Tracer()
+        tr.trace_method(reporter, 'exit_testcase')
+        runner.run_class(testclass)
+        self.assertEqual(len(tr), 2)
+        #
+        self.assertEqual(tr[0].args[1], 'test_1')
+        self.assertEqual(tr[0].args[2], oktest.ST_FAILED)
+        exc_info_list = tr[0].args[3]
+        assert isinstance(exc_info_list, list)
+        exs = [ exc_info[1] for exc_info in exc_info_list ]
+        self.assertEqual(exs[0].args, ('*** failed ***',))
+        self.assertEqual(exs[1].args, ('*** @at_end ***',))
+        self.assertEqual(exs[2].args, ('*** tearDown() ***',))
+        self.assertEqual(len(exs), 3)
+        #
+        self.assertEqual(tr[1].args[1], 'test_2')
+        self.assertEqual(tr[1].args[2], oktest.ST_ERROR)
+        exc_info_list = tr[1].args[3]
+        assert isinstance(exc_info_list, list)
+        exs = [ exc_info[1] for exc_info in exc_info_list ]
+        self.assertEqual(exs[0].args, ('*** test_2() ***',))
+        self.assertEqual(exs[1].args, ('*** @at_end ***',))
+        self.assertEqual(exs[2].args, ('*** tearDown() ***',))
+        self.assertEqual(len(exs), 3)
+
+
     def test_run_without_args(self):
         desc = "run (without args)"
         script = r"""
@@ -414,7 +469,7 @@ run(FooTest)
         expected = r"""
 * <b>FooTest</b>: .<R>f</R><R>E</R><R>f</R>
 <r>----------------------------------------------------------------------</r>
-[<R>Failed</R>] FooTest > test_failed()
+[<R>Fail</R>] FooTest > test_failed()
   File "_test_.py", line 9, in test_failed
     ok (1+1) == 3
 <R>AssertionError: 2 == 3 : failed.</R>
@@ -424,7 +479,7 @@ run(FooTest)
     ok (int('aaa')) == 0
 <R>ValueError: invalid literal for int() with base 10: 'aaa'</R>
 <r>----------------------------------------------------------------------</r>
-[<R>Failed</R>] FooTest > test_nested()
+[<R>Fail</R>] FooTest > test_nested()
   File "_test_.py", line 13, in test_nested
     self._test1()
   File "_test_.py", line 15, in _test1
@@ -433,7 +488,7 @@ run(FooTest)
     ok (1+1) == 0
 <R>AssertionError: 2 == 0 : failed.</R>
 <r>----------------------------------------------------------------------</r>
-## total:4, <G>passed:1</G>, <R>failed:2</R>, <R>error:1</R>, skipped:0, todo:0  (0.000 sec)
+## total:4, <G>pass:1</G>, <R>fail:2</R>, <R>error:1</R>, skip:0, todo:0  (0.000 sec)
 """[1:]
         if python24:
             expected = expected.replace("int() with base 10: 'aaa'", 'int(): aaa')
@@ -468,24 +523,24 @@ run(BarTest)
         expected = r"""
 * <b>BarTest</b>: <R>f</R><R>f</R><R>f</R>
 <r>----------------------------------------------------------------------</r>
-[<R>Failed</R>] BarTest > test_sample1()
+[<R>Fail</R>] BarTest > test_sample1()
 Sample Description 1
   File "_test_.py", line 9, in test_sample1
     ok (0) == 1
 <R>AssertionError: 0 == 1 : failed.</R>
 <r>----------------------------------------------------------------------</r>
-[<R>Failed</R>] BarTest > test_sample2()
+[<R>Fail</R>] BarTest > test_sample2()
 Sample Description 2
   File "_test_.py", line 13, in test_sample2
     ok (0) == 2
 <R>AssertionError: 0 == 2 : failed.</R>
 <r>----------------------------------------------------------------------</r>
-[<R>Failed</R>] BarTest > 002: Sample Description 3
+[<R>Fail</R>] BarTest > 002: Sample Description 3
   File "_test_.py", line 17, in _
     ok (0) == 3
 <R>AssertionError: 0 == 3 : failed.</R>
 <r>----------------------------------------------------------------------</r>
-## total:3, passed:0, <R>failed:3</R>, error:0, skipped:0, todo:0  (0.000 sec)
+## total:3, pass:0, <R>fail:3</R>, error:0, skip:0, todo:0  (0.000 sec)
 """[1:]
         os.environ['OKTEST_REPORTER'] = 'SimpleReporter'
         oktest.REPORTER = oktest.SimpleReporter
@@ -635,6 +690,52 @@ run(FooTest)
         self.do_test(desc, script, expected)
 
 
+    def test_diff_pformat(self):
+        ### diff (using pformat)
+        desc = "diff (using pformat)"
+        script = r"""
+from oktest import *
+import oktest
+class FooTest(object):
+    def test1(self):
+        expected = {
+          'members': [
+            {'name': 'Haruhi Suzumiya', 'gender': 'F', 'role': 'Leader of SOS Brigade'},
+            {'name': 'Mikuru Asahina',  'gender': 'F', 'role': 'Time Traveler'},
+            {'name': 'Yuki Nagato',     'gender': 'F', 'role': 'Humanoid Interface'},
+          ]
+        }
+        actual = {
+          'members': [
+            {'name': 'Haruhi Suzumiya', 'gender': 'F', 'role': 'Leader of SOS Brigade'},
+            {'name': 'Michiru Asahina', 'gender': 'F', 'role': 'Time Traveler'},
+            {'name': 'Yuki Nagato',     'gender': 'F', 'role': 'Just an ordinary girl'},
+          ]
+        }
+        ok (actual) == expected
+run(FooTest)
+"""[1:]
+        expected = r"""
+* FooTest.test1 ... [NG] {'members': [{'gender': 'F', 'role': 'Leader of SOS Brigade', 'name': 'Haruhi Su [truncated]... == {'members': [{'gender': 'F', 'role': 'Leader of SOS Brigade', 'name': 'Haruhi Su [truncated]... : failed.
+   _test_.py:19: ok (actual) == expected
+--- expected
++++ actual
+@@ -3,7 +3,7 @@
+               'role': 'Leader of SOS Brigade'},
+              {'gender': 'F',
+-              'name': 'Mikuru Asahina',
++              'name': 'Michiru Asahina',
+               'role': 'Time Traveler'},
+              {'gender': 'F',
+               'name': 'Yuki Nagato',
+-              'role': 'Humanoid Interface'}]}
+\ No newline at end of string
++              'role': 'Just an ordinary girl'}]}
+\ No newline at end of string
+"""[1:]
+        self.do_test(desc, script, expected)
+
+
 
 if __name__ == '__main__':
     unittest.main()
