@@ -1,6 +1,7 @@
+# -*- coding: utf-8 -*-
 ###
-### $Release: 0.11.1 $
-### $Copyright: copyright(c) 2010-2011 kuwata-lab.com all rights reserved $
+### $Release: 0.12.0 $
+### $Copyright: copyright(c) 2010-2014 kuwata-lab.com all rights reserved $
 ### $License: MIT License $
 ###
 
@@ -81,9 +82,9 @@ class Skip_TC(unittest.TestCase):
     def test_runner_should_handle_SkipTest(self):
         expected = r"""
 * <b>_RunnterHandleSkipTest</b>
-  - [<Y>skipped</Y>] test1 (reason: reason #1)
-  - [<Y>skipped</Y>] test2 (reason: reason #2)
-## total:2, passed:0, failed:0, error:0, <Y>skipped:2</Y>, todo:0  (0.000 sec)
+  - [<Y>skip</Y>] test1 (reason: reason #1)
+  - [<Y>skip</Y>] test2 (reason: reason #2)
+## total:2, pass:0, fail:0, error:0, <Y>skip:2</Y>, todo:0  (0.000 sec)
 """[1:]
         self._test_runner(expected, Skip_TC._RunnterHandleSkipTest)
 
@@ -106,9 +107,9 @@ class Skip_TC(unittest.TestCase):
         def test_runner_should_handle_unittests_SkipTest(self):
             expected = r"""
 * <b>_RunnterHandleUnittestSkipTest</b>
-  - [<Y>skipped</Y>] test1 (reason: reason1)
-  - [<Y>skipped</Y>] test2 (reason: reason2)
-## total:2, passed:0, failed:0, error:0, <Y>skipped:2</Y>, todo:0  (0.000 sec)
+  - [<Y>skip</Y>] test1 (reason: reason1)
+  - [<Y>skip</Y>] test2 (reason: reason2)
+## total:2, pass:0, fail:0, error:0, <Y>skip:2</Y>, todo:0  (0.000 sec)
 """[1:]
             self._test_runner(expected, Skip_TC._RunnterHandleUnittestSkipTest)
 
@@ -130,10 +131,10 @@ class Skip_TC(unittest.TestCase):
         def test_skip_is_avaialbe_with_test_decorator(self):
             expected = r"""
 * <b>_AvailableWithTestDecorator</b>
-  - [<Y>skipped</Y>] desc7 (reason: reason7)
-  - [<Y>skipped</Y>] desc2 (reason: reason2)
-  - [<G>passed</G>] desc3
-## total:3, <G>passed:1</G>, failed:0, error:0, <Y>skipped:2</Y>, todo:0  (0.000 sec)
+  - [<Y>skip</Y>] desc7 (reason: reason7)
+  - [<Y>skip</Y>] desc2 (reason: reason2)
+  - [<G>pass</G>] desc3
+## total:3, <G>pass:1</G>, fail:0, error:0, <Y>skip:2</Y>, todo:0  (0.000 sec)
 """[1:]
             self._test_runner(expected, Skip_TC._AvailableWithTestDecorator)
 
