@@ -1,6 +1,7 @@
+# -*- coding: utf-8 -*-
 ###
-### $Release: 0.11.1 $
-### $Copyright: copyright(c) 2010-2011 kuwata-lab.com all rights reserved $
+### $Release: 0.12.0 $
+### $Copyright: copyright(c) 2010-2014 kuwata-lab.com all rights reserved $
 ### $License: MIT License $
 ###
 
@@ -22,7 +23,7 @@ class Todo_TC(unittest.TestCase):
 
     ### @todo()
 
-    def test_todo_1(self):
+    def test_todo__when_failed_expectdly(self):
         """
         test method decorated by @todo should raises _ExpectedFailure exception
         with assertion information when it failed expectedly.
@@ -41,9 +42,9 @@ class Todo_TC(unittest.TestCase):
             assert ex.exc_info[0] == AssertionError
             assert str(ex.exc_info[1]) == "DESC1"
 
-    def test_todo_2(self):
+    def test_todo__when_passed_unexpectedly(self):
         """
-        test method decorated by @todo should raises _UnExpectedSuccess exception
+        test method decorated by @todo should raise _UnExpectedSuccess exception
         without assertion information when it passed unexpectedly.
         """
         @todo
@@ -84,12 +85,12 @@ class Todo_TC(unittest.TestCase):
         expected = r"""
 * <b>_RunnerHandleExpectedFailureTest</b>
   - [<Y>TODO</Y>] test1
-  - [<R>Failed</R>] test2
+  - [<R>Fail</R>] test2
 <r>----------------------------------------------------------------------</r>
-[<R>Failed</R>] _RunnerHandleExpectedFailureTest > test2()
+[<R>Fail</R>] _RunnerHandleExpectedFailureTest > test2()
 <R>_UnexpectedSuccess: test should be failed (because not implemented yet), but passed unexpectedly.</R>
 <r>----------------------------------------------------------------------</r>
-## total:2, passed:0, <R>failed:1</R>, error:0, skipped:0, <Y>todo:1</Y>  (0.000 sec)
+## total:2, pass:0, <R>fail:1</R>, error:0, skip:0, <Y>todo:1</Y>  (0.000 sec)
 """[1:]
         self._test_runner(expected, Todo_TC._RunnerHandleExpectedFailureTest, 1)
 
@@ -112,12 +113,12 @@ class Todo_TC(unittest.TestCase):
             expected = r"""
 * <b>_RunnerHandleUnittestExpectedFailure</b>
   - [<Y>TODO</Y>] test1
-  - [<R>Failed</R>] test2
+  - [<R>Fail</R>] test2
 <r>----------------------------------------------------------------------</r>
-[<R>Failed</R>] _RunnerHandleUnittestExpectedFailure > test2()
+[<R>Fail</R>] _RunnerHandleUnittestExpectedFailure > test2()
 <R>_UnexpectedSuccess: test should be failed (because not implemented yet), but passed unexpectedly.</R>
 <r>----------------------------------------------------------------------</r>
-## total:2, passed:0, <R>failed:1</R>, error:0, skipped:0, <Y>todo:1</Y>  (0.000 sec)
+## total:2, pass:0, <R>fail:1</R>, error:0, skip:0, <Y>todo:1</Y>  (0.000 sec)
 """[1:]
             self._test_runner(expected, Todo_TC._RunnerHandleUnittestExpectedFailure, 1)
 
@@ -145,24 +146,59 @@ class Todo_TC(unittest.TestCase):
         def test_todo_is_avaialbe_with_test_decorator(self):
             expected = r"""
 * <b>_TodoIsAvailableWithTestDecorator</b>
-  - [<R>Failed</R>] SPEC3
-  - [<G>passed</G>] SPEC4
+  - [<R>Fail</R>] SPEC3
+  - [<G>pass</G>] SPEC4
   - [<Y>TODO</Y>] SPEC1
-  - [<R>Failed</R>] SPEC2
+  - [<R>Fail</R>] SPEC2
 <r>----------------------------------------------------------------------</r>
-[<R>Failed</R>] _TodoIsAvailableWithTestDecorator > 003: SPEC3
-  File "test/todo_test.py", line 138, in _
+[<R>Fail</R>] _TodoIsAvailableWithTestDecorator > 003: SPEC3
+  File "test/todo_test.py", line 139, in _
     assert 1 == 0, "expected failure"
 <R>AssertionError: expected failure</R>
 <r>----------------------------------------------------------------------</r>
-[<R>Failed</R>] _TodoIsAvailableWithTestDecorator > 002: SPEC2
+[<R>Fail</R>] _TodoIsAvailableWithTestDecorator > 002: SPEC2
 <R>_UnexpectedSuccess: test should be failed (because not implemented yet), but passed unexpectedly.</R>
 <r>----------------------------------------------------------------------</r>
-## total:4, <G>passed:1</G>, <R>failed:2</R>, error:0, skipped:0, <Y>todo:1</Y>  (0.000 sec)
+## total:4, <G>pass:1</G>, <R>fail:2</R>, error:0, skip:0, <Y>todo:1</Y>  (0.000 sec)
 """[1:]
             self._test_runner(expected, Todo_TC._TodoIsAvailableWithTestDecorator, 2)
 
 
+        class _TodoIsAvailableWithFixtureArguments(object):
+            def provide_a(self):
+                return "AAA"
+            def provide_b(self):
+                return "BBB"
+            def provide_c(self):
+                return "CCC"
+            #
+            @test("WILL FAIL BECAUSE PASSED UNEXPECTEDLY")
+            @todo
+            def _(self, a, b, c="---"):
+                assert a == "AAA", "expected failure"
+                assert b == "BBB", "expected failure"
+                assert c == "---", "expected failure"
+            #
+            @test("WILL PASS BECAUSE FAILED EXPECTEDLY")
+            @todo
+            def _(self, a, b):
+                assert False
+
+        def test_todo_is_avaialbe_with_fixture_arguments(self):
+            expected = r"""
+* <b>_TodoIsAvailableWithFixtureArguments</b>
+  - [<R>Fail</R>] WILL FAIL BECAUSE PASSED UNEXPECTEDLY
+  - [<Y>TODO</Y>] WILL PASS BECAUSE FAILED EXPECTEDLY
+<r>----------------------------------------------------------------------</r>
+[<R>Fail</R>] _TodoIsAvailableWithFixtureArguments > 001: WILL FAIL BECAUSE PASSED UNEXPECTEDLY
+<R>_UnexpectedSuccess: test should be failed (because not implemented yet), but passed unexpectedly.</R>
+<r>----------------------------------------------------------------------</r>
+## total:2, pass:0, <R>fail:1</R>, error:0, skip:0, <Y>todo:1</Y>  (0.000 sec)
+"""[1:]
+
+            self._test_runner(expected, Todo_TC._TodoIsAvailableWithFixtureArguments, 1)
+
+
 
 if __name__ == '__main__':
     unittest.main()
