@@ -1,17 +1,21 @@
 # -*- coding: utf-8 -*-
-
 ###
-### $Release: 0.11.1 $
-### $Copyright: copyright(c) 2010-2011 kuwata-lab.com all rights reserved $
+### $Release: 0.12.0 $
+### $Copyright: copyright(c) 2010-2014 kuwata-lab.com all rights reserved $
 ### $License: MIT License $
 ###
+from __future__ import with_statement
 
 import sys, os, re, shutil
+try:
+    xrange
+except NameError:
+    xrange = range
 import unittest
 import oktest
 from oktest import ok, NG, run
 from oktest import python2, python3
-from oktest.util import chdir, flatten, rm_rf, zenkaku_width, zenkaku_shorten
+from oktest.util import chdir, flatten, rm_rf, from_here, randstr, zenkaku_width, zenkaku_shorten
 
 
 available_with_statement = sys.version_info[0:2] > (2, 4)
@@ -240,6 +244,50 @@ class util_TC(unittest.TestCase):
             self._after_rm_rf()
 
 
+    def test_from_here_1(self):
+        old = sys.path[:]
+        currpath = os.path.join(os.getcwd(), os.path.dirname(__file__), 'foobar')
+        expected = [currpath] + old
+        with from_here('foobar'):
+            ok (sys.path) == expected
+        ok (sys.path) != expected
+        ok (sys.path) == old
+
+    def test_from_here_2(self):
+        old = sys.path[:]
+        currpath = os.path.join(os.getcwd(), os.path.dirname(__file__), '../foobar')
+        expected = [os.path.realpath(currpath)] + old
+        with from_here('../foobar'):
+            ok (sys.path) == expected
+        ok (sys.path) != expected
+        ok (sys.path) == old
+
+    def test_from_here_3(self):
+        old = sys.path[:]
+        abspath = os.path.dirname(os.path.abspath(__file__))
+        expected = [abspath] + old
+        with from_here():
+            ok (sys.path) == expected
+        ok (sys.path) != expected
+        ok (sys.path) == old
+
+
+    def test_randstr_1(self):
+        for _ in xrange(10):
+            s = randstr()
+            ok (s).is_a(str).length(8).matches(r'^\d+$')
+
+    def test_randstr_2(self):
+        n = 4
+        for _ in xrange(10):
+            s = randstr(n)
+            ok (s).is_a(str).length(n).matches(r'^\d+$')
+
+    def test_randstr_3(self):
+        arr = [ randstr() for _ in xrange(100) ]
+        ok (len(arr)) == len(set(arr))
+
+
     def _do_test(self, input):
         fname = "__test_input.txt"
         if python2:
